searchData={"items":[{"type":"module","title":"Pinout","doc":"Pinout detects popular embedded devices and prints out pinout diagrams.","ref":"Pinout.html"},{"type":"function","title":"Pinout.detect/0","doc":"Return the name of the current board","ref":"Pinout.html#detect/0"},{"type":"function","title":"Pinout.known_boards/0","doc":"Get a list of boards known to the Pinout library","ref":"Pinout.html#known_boards/0"},{"type":"function","title":"Examples - Pinout.known_boards/0","doc":"iex> Pinout.known_boards()\n    [\"BeagleBone Black\", \"BeagleBone Black Wireless\", \"BeagleBone Blue\",\n    \"BeagleBone Green Wireless\", \"GRiSP2\", \"MangoPi MQ-Pro\", \"NPi i.MX6 ULL\",\n    \"PocketBeagle\", \"Raspberry Pi 2B\", \"Raspberry Pi 3B\", \"Raspberry Pi 3B+\",\n    \"Raspberry Pi 400\", \"Raspberry Pi 4B\", \"Raspberry Pi 5B\",\n    \"Raspberry Pi T-Cobbler\", \"Raspberry Pi Zero 2 W\", \"Raspberry Pi Zero W\"]","ref":"Pinout.html#known_boards/0-examples"},{"type":"function","title":"Pinout.pinout_content/0","doc":"Return the pinout as IO.ANSI.ansidata\n\nIf you'd like to use the pinout information and not print it to the terminal,\ncall this function to get the raw ansidata version of it. To convert this to\na string, call `IO.ANSI.format/1` and then pass the result to\n`IO.chardata_to_string/1`.","ref":"Pinout.html#pinout_content/0"},{"type":"function","title":"Pinout.pinout_content/1","doc":"Returns the pinout for a specific board as IO.ANSI.ansidata","ref":"Pinout.html#pinout_content/1"},{"type":"function","title":"Pinout.print/0","doc":"Prints the pinout for the current board","ref":"Pinout.html#print/0"},{"type":"function","title":"Examples - Pinout.print/0","doc":"#=> Pinout.print()\n    ╭------------------------╮\n    |  oooooooooooooooooooo  |\n    |  1ooooooooooooooooooo  |\n    |  Raspberry Pi Zero W   |\n    |  ╭---╮     ╭--╮  ╭--╮  |\n    ╰--╰---╯-----╰--╯--╰--╯--╯\n             3v3 Power  [1] [2]  5v Power\n       GPIO 2/I2C1 SDA  [3] [4]  5v Power\n       GPIO 3/I2C1 SCL  [5] [6]  Ground\n         GPIO 4/GPCLK0  [7] [8]  GPIO 14/UART TX\n                Ground  [9] [10] GPIO 15/UART RX\n               GPIO 17 [11] [12] GPIO 18/PCM CLK\n               GPIO 27 [13] [14] Ground\n               GPIO 22 [15] [16] GPIO 23\n             3v3 Power [17] [18] GPIO 24\n     GPIO 10/SPI0 MOSI [19] [20] Ground\n      GPIO 9/SPI0 MISO [21] [22] GPIO 25\n     GPIO 11/SPI0 SCLK [23] [24] GPIO 8/SPI0 CE0\n                Ground [25] [26] GPIO 7/SPI0 CE1\n     GPIO 0/EEPROM SDA [27] [28] GPIO 1/EEPROM SCL\n                GPIO 5 [29] [30] Ground\n                GPIO 6 [31] [32] GPIO 12/PWM0\n          GPIO 13/PWN1 [33] [34] Ground\n        GPIO 19/PCM FS [35] [36] GPIO 16\n               GPIO 26 [37] [38] GPIO 20/PCM DIN\n                Ground [39] [40] GPIO 21/PCM DOUT","ref":"Pinout.html#print/0-examples"},{"type":"function","title":"Pinout.print/1","doc":"Print out the pinout for a specific board\n\nCall `Pinout.known_boards/0` for a list of boards","ref":"Pinout.html#print/1"},{"type":"function","title":"Examples - Pinout.print/1","doc":"#=> Pinout.print(\"Raspberry Pi 4B\")\n    ╭----------------------------------╮\n    |  oooooooooooooooooooo       ╭-----╮\n    |  1ooooooooooooooooooo       |     |\n    |                             ╰-----╯\n    |                             ╭-----╮\n    |       Raspberry Pi 4B       |     |\n    |                             ╰-----╯\n    |                           ╭-------╮\n    |          ╭------╮         |       |\n    |  ╭--╮    |      |         ╰-------╯\n    ╰--╰--╯----╰------╯-----------------╯\n            3v3 Power  [1] [2]  5v Power\n      GPIO 2/I2C1 SDA  [3] [4]  5v Power\n      GPIO 3/I2C1 SCL  [5] [6]  Ground\n        GPIO 4/GPCLK0  [7] [8]  GPIO 14/UART TX\n               Ground  [9] [10] GPIO 15/UART RX\n              GPIO 17 [11] [12] GPIO 18/PCM CLK\n              GPIO 27 [13] [14] Ground\n              GPIO 22 [15] [16] GPIO 23\n            3v3 Power [17] [18] GPIO 24\n    GPIO 10/SPI0 MOSI [19] [20] Ground\n    GPIO 9/SPI0 MISO  [21] [22] GPIO 25\n    GPIO 11/SPI0 SCLK [23] [24] GPIO 8/SPI0 CE0\n               Ground [25] [26] GPIO 7/SPI0 CE1\n    GPIO 0/EEPROM SDA [27] [28] GPIO 1/EEPROM SCL\n               GPIO 5 [29] [30] Ground\n               GPIO 6 [31] [32] GPIO 12/PWM0\n         GPIO 13/PWN1 [33] [34] Ground\n       GPIO 19/PCM FS [35] [36] GPIO 16\n              GPIO 26 [37] [38] GPIO 20/PCM DIN\n               Ground [39] [40] GPIO 21/PCM DOUT","ref":"Pinout.html#print/1-examples"},{"type":"extras","title":"Pinout","doc":"# Pinout\n\n[![CircleCI](https://circleci.com/gh/cavocado/pinout.svg?style=svg)](https://circleci.com/gh/cavocado/pinout)\n[![Hex version](https://img.shields.io/hexpm/v/pinout.svg \"Hex version\")](https://hex.pm/packages/pinout)\n\nPinout detects popular embedded devices and prints out pinout diagrams.","ref":"readme.html"},{"type":"extras","title":"Usage - Pinout","doc":"Add `pinout` to your project's dependency list:\n\n```elixir\ndef deps do\n  [\n    {:pinout, \"~> 0.1\"}\n  ]\nend\n```\n\nBuild and then run `Pinout.print()` at the IEx prompt.","ref":"readme.html#usage"},{"type":"extras","title":"Nerves + Livebook - Pinout","doc":"[Nerves Livebook project](https://github.com/nerves-livebook/nerves_livebook)\nallows you to try out the Nerves project on real hardware without needing\nto build a project from scratch.\n\nWithin minutes, you'll have a Raspberry Pi or Beaglebone running Nerves. You'll\nbe able to run code in [Livebook](https://livebook.dev/) and work through\nNerves tutorials from the comfort of your browser.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fcavocado%2Fpinout%2Fblob%2Fmain%2Fnotebooks%2Fbasics.livemd)","ref":"readme.html#nerves-livebook"},{"type":"extras","title":"Adding new boards - Pinout","doc":"To add support for a new board, do the following:\n\n1. Copy `/sys/firmware/devicetree/base` directory off the new board and add it\n   under the `test/fixture` directory like other boards.\n   a. This can be accomplished with a command like\n      `scp -R nerves.local:/sys/firmware/devicetree/base .`\n2. Find a board in `lib/pinout/db/boards.ex` that's similar to the new one and\n   use it as a template for the new board.\n3. If the new board has a new pinout, add the pinout information to\n   `lib/pinout/db/connectors.ex`\n4. Finally, if the board needs new artwork, add the new ASCII art to\n   `lib/pinout/art.ex`\n5. Send a PR! :)","ref":"readme.html#adding-new-boards"},{"type":"extras","title":"License - Pinout","doc":"Copyright (C) 2022 Alexa Hunleth\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.5 - Changelog","doc":"* Updates\n  * Relax board matching to not be tricked by new versions of Raspberry Pis","ref":"changelog.html#v0-1-5"},{"type":"extras","title":"v0.1.4 - Changelog","doc":"* Updates\n  * Added Raspberry Pi 5B (Thanks @mnishiguchi)","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Updates\n  * Added Raspberry Pi 3B+ (Thanks @axelson)","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* Updates\n  * Added Raspberry Pi T-Cobbler (Thanks @dkuku)","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Updates\n  * Improved MangoPi and PocketBeagle pinouts","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}